#include "proteincode_lib.h"


void
FastaProteinArrayHandler::setSequence(const QString &description_in,
                                      const QString &sequence_in)
{
  m_proteinArray.push_back({description_in, sequence_in});
}

const std::vector<pappso::Protein> &
FastaProteinArrayHandler::getProteinArray() const
{
  return m_proteinArray;
};


void
writeProteinConvolutionScore(
  const QString &filename,
  const pappso::Protein &protein,
  const pappso::ProteinPresenceAbsenceMatrix *pmatrix,
  const std::vector<double> &convolution_score)
{

  QFile file(filename);
  // file.open(QIODevice::WriteOnly);
  OdsDocWriter writer(&file);

  writer.writeSheet(protein.getAccession());
  writer.writeCell("sequence");
  for(long long i = 0; i < protein.getSequence().size(); i++)
    {
      writer.writeCell(protein.getSequence()[i]);
    }
  writer.writeLine();
  writer.writeCell("convolution score");
  for(long long i = 0; i < protein.getSequence().size(); i++)
    {
      writer.writeCell(convolution_score[i]);
    }
  writer.writeLine();
  if(pmatrix != nullptr)
    {


      auto matrix = pmatrix->getPresenceAbsenceMatrix();
      for(long long j = 0; j < 5; j++)
        {

          writer.writeCell(QString("%1aa").arg(j + 1));
          for(long long i = 0; i < protein.getSequence().size(); i++)
            {

              if(matrix(i, j) == pappso::ProteinPresenceAbsenceMatrix::
                                   ProteinPresenceAbsenceMatrixElement::present)
                {
                  writer.writeCell("X");
                }
              else
                {
                  writer.writeEmptyCell();
                }
            }

          writer.writeLine();
        }
    }

  writer.close();
}
